
config more[off]
spool file[p_hww02.out]


# PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)
# FACULTY:		Dan McFadden
# AUTHOR:		Peter Adams
# LAST UPDATE:		February 05, 2003
# PROGRAM DESC:		New Incidence Probits (White Females)


load file[hww123]


save file[junk]


# ====================================================================
# DEFINE STACKED VARIABLES
# ====================================================================

# SET OBSERVATIONS
# --------------------------------------------------------------------

range obs[1-12978]
set ndx=obsno

set ndx12=ndx
match key[ndx12] file[junk]
set ndx23=ndx
match key[ndx23] file[junk]

set dd12=(ndx <= 6489)
set dd23=(1 - dd12)*(inw2==1)
set dd13=dd12|dd23

set zero=zero
set one=one

# DEFINE STACKING MACRO
# --------------------------------------------------------------------

macro stk(a,b,c) {
 set a=b; if[dd12] rp
 set a=c; if[dd23]
}

# VARIANT STACKED VARIABLES
# --------------------------------------------------------------------

@stk(one1,one,zero)
@stk(one2,zero,one)
@stk(one12,one,one)
@stk(zero12,zero,zero)

@stk(lmonth1,lmonth12,zero)
@stk(lmonth2,zero,lmonth23)
@stk(lmonth,lmonth12,lmonth23)

@stk(logm1,logm12,zero)
@stk(logm2,zero,logm23)
@stk(logm,logm12,logm23)

@stk(as70m1,as701,zero)
@stk(as70m2,zero,as702)
@stk(as70m12,as701,as702)

@stk(as80m1,as801,zero)
@stk(as80m2,zero,as802)
@stk(as80m12,as801,as802)

@stk(male12,male,male)
@stk(white12,white,white)
@stk(sample23,sample2,sample3)

# DEMOGRAPHICS
# --------------------------------------------------------------------

@stk(nevmar12,nevmarr1,nevmarr2)
@stk(widow12,widow1,widow2)
@stk(divsep12,divsep1,divsep2)
@stk(magedi12,magedie1,magedie1) 
@stk(pagedi12,pagedie1,pagedie1) 
@stk(smokev12,smokev,smokev)

# SOCIO-ECONOMIC STATUS
# --------------------------------------------------------------------

@stk(q1wc12,q1wc1,q1wc2)
@stk(q4wc12,q4wc1,q4wc2) 
@stk(q1ic12,q1ic1,q1ic2) 
@stk(q4ic12,q4ic1,q4ic2) 

@stk(q1wb12,q1wb1,q1wb2)
@stk(q4wb12,q4wb1,q4wb2) 
@stk(q1ib12,q1ib1,q1ib2) 
@stk(q4ib12,q4ib1,q4ib2) 

@stk(hs12,hs,hs) 
@stk(coll12,coll,coll) 
@stk(hoodpf12,hoodpf1,hoodpf2) 
@stk(condpf12,condpf1,condpf2)

@stk(cwlth23,cwlth2,cwlth3)

# INDEPENDENT HEALTH CONDITIONS
# --------------------------------------------------------------------

@stk(canc12,cancer1,cancer2) 
@stk(heart12,heart1,heart2)
@stk(strk12,stroke1,stroke2) 
@stk(lung12,lung1,lung2) 
@stk(diab12,diabet1,diabet2)
@stk(high12,highbp1,highbp2)
@stk(arth12,arthrt1,arthrt2)
@stk(incon12,incont1,incont2)
@stk(fall12,fall1,fall2)
@stk(hip12,hipfrc1,hipfrc2)
@stk(proxy12,proxyw1,proxyw2)
@stk(cog12,cogim1,cogim2)
@stk(psych12,psych1,psych2)
@stk(depr12,depres1,depres2)
@stk(bmi12,bmi1,bmi2)
@stk(lobmi12,lobmi1,lobmi2)
@stk(hibmi12,hibmi1,hibmi2)
@stk(smok12,smoknow1,smoknow2)
@stk(adl12,numadl1,numadl2)
@stk(iadl12,numiadl1,numiadl2)
@stk(dhlth12,dhlth1,dhlth2)

# DEPENDENT HEALTH CONDITIONS 
# --------------------------------------------------------------------

@stk(jcanc23,jcancer2,jcancer3) 
@stk(jheart23,jheart2,jheart3) 
@stk(jstrk23,jstroke2,jstroke3)
@stk(mort23,tdied2,tdied3)
@stk(ilung23,ilung2,ilung3) 
@stk(idiab23,idiabet2,idiabet3)
@stk(ihigh23,ihighbp2,ihighbp3) 
@stk(iarth23,iarthrt2,iarthrt3) 
@stk(jincon23,jincont2,jincont3)
@stk(jfall23,jfall2,jfall3) 
@stk(jhip23,jhipfrc2,jhipfrc3) 
@stk(proxy23,proxyw2,proxyw3)
@stk(icog23,icogim2,icogim3)
@stk(ipsych23,ipsych2,ipsych3) 
@stk(idepr23,idepres2,idepres3) 
@stk(bmi23,bmi2,bmi3)
@stk(bmibt23,bmibt2,bmibt3)
@stk(bmiws23,bmiws2,bmiws3)
@stk(smok23,smoknow2,smoknow3)
@stk(adl23,numadl2,numadl3)
@stk(iadl23,numiadl2,numiadl3)
@stk(dhlth23,dhlth2,dhlth3)
@stk(hoodpf23,hoodpf2,hoodpf3)
@stk(condpf23,condpf2,condpf3)


# ====================================================================
# DEFINE INDEPENDENT VARIABLE MACROS
# ====================================================================

# AGE
# --------------------------------------------------------------------

macro m_age1m { as70m1, as80m1 }
macro m_age2m { as70m2, as80m2 }

# DEMOGRAPHICS
# --------------------------------------------------------------------

macro m_dem12 { nevmar12, widow12, divsep12, magedi12, pagedi12, \
	smokev12 }
macro m_dem12a { nevmar12, widow12, divsep12, magedi12, pagedi12 }

# SOCIO-ECONOMIC STATUS
# --------------------------------------------------------------------

macro m_ses12 { q1wb12, q4wb12, q1ib12, q4ib12, hs12, coll12, \
	hoodpf12, condpf12 }

# STACKED HEALTH CONDITIONS
# --------------------------------------------------------------------

macro m_canc { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12 }

macro m_canc0 { heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12 }

macro m_heart { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23 }

macro m_heart0 { canc12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23 }

macro m_strk { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23}

macro m_strk0 { canc12, heart12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23}

macro m_mort { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23}

macro m_lung { canc12, heart12, strk12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23}

macro m_diab { canc12, heart12, strk12, lung12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23}

macro m_high { canc12, heart12, strk12, lung12, diab12, \
	arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23 }

macro m_arth { canc12, heart12, strk12, lung12, diab12, \
	high12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23 }

macro m_incon { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23 }

macro m_incon0 { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23 }

macro m_fall { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23 }

macro m_fall0 { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23 }

macro m_hip { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23 }

macro m_hip0 { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23 }

macro m_prox { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23 }

macro m_prox0 { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23 }

macro m_prox0b { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, cog12, \
	psych12,        lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23,            \
	ihigh23, iarth23, jincon23, jfall23, jhip23 }

macro m_cog { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23, proxy23 }

macro m_psych { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23, proxy23, \
	icog23 }

macro m_depr { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23, proxy23, \
	icog23, ipsych23 }

macro m_bmi { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, bmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23, proxy23, \
	icog23, ipsych23, idepr23 }

macro m_smok { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23, proxy23, \
	icog23, ipsych23, idepr23, bmibt23, bmiws23 }

macro m_smok0 { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23, proxy23, \
	icog23, ipsych23, idepr23, bmibt23, bmiws23 }

macro m_adl { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23, proxy23, \
	icog23, ipsych23, idepr23, bmibt23, bmiws23, smok23 }

macro m_iadl { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23, proxy23, \
	icog23, ipsych23, idepr23, bmibt23, bmiws23, smok23, \
	adl23 }

macro m_hlth { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23, proxy23, \
	icog23, ipsych23, idepr23, bmibt23, bmiws23, smok23, \
	adl23, iadl23 }

macro m_hlth0 { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23, proxy23, \
	icog23, ipsych23, idepr23, bmibt23, bmiws23, smok23, \
	adl23, iadl23 }


# ====================================================================
# DEFINE DEPENDENT VARIABLE LABEL ARRAY
# ====================================================================

array a_label = ( CANCER \
	CANCER_noprev \
	CANCER_prev \
	HEART \
	HEART_noprev \
	HEART_prev \
	STROKE \
	STROKE_noprev \
	STROKE_prev \
	MORTALITY \
	LUNG \
	DIABETES \
	HIGH_BLOOD_PRESSURE \
	ARTHRITIS \
	INCONTINENCE \
	INCONTINENCE_noprev \
	INCONTINENCE_prev \
	FALL \
	FALL_noprev \
	FALL_prev \
	HIP_FRACTURE \
	HIP_FRACTURE_noprev \
	HIP_FRACTURE_prev \
	PROXY_INTERVIEW \
	PROXY_INTERVIEW_noprev \
	PROXY_INTERVIEW_prev \
	COGNITIVE_IMPAIRMENT \
	PSYCHIATRIC \
	DEPRESSION \
	BODY_MASS_INDEX \
	CURRENT_SMOKER \
	CURRENT_SMOKER_noprev \
	CURRENT_SMOKER_prev \
	ACTIVITIES_DAILY_LIVING \
	INSTRUMENTAL_ACTIVITIES_DAILY_LIVING \
	SELF_HEALTH_POOR/FAIR \
	SELF_HEALTH_POOR/FAIR_noprev \
	SELF_HEALTH_POOR/FAIR_prev )


# ====================================================================
# DEFINE SIGNIFICANCE TEST MATRICES
# ====================================================================

matrix CHI2=zeros(39,6)
matrix DF=zeros(39,6)


# ====================================================================
# DEFINE PROBIT REGRESSION MACRO
# ====================================================================

config precis[digits=5]

macro p_stk(i,a,b,c,d,e,f) {

set missing=miss(a, one12, one1, one2, logm, logm1, logm2, \
	@m_age1m, @m_age2m, @b, @c, @d)
	
echo
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
echo i. $a_label[i] : PARAMETER ESTIMATES
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

echo
echo i.1 WAVE 1-2 (NO INVARIANCE, INCLUDE SES)
echo -----------------------------------------------------------------

probit dep[a] ind[one12 logm @m_age1m @b @c @d] \
	maxit[50] \
	if[(male12==0)&(white12==1)&(dd12==1)&(e==0)&(f)&(missing==0)]
calc llk1=_llk
array a_indvar = (@m_age1m @b @c @d)
calc d1 = 2+$#a_indvar
calc d1

echo
echo i.2 WAVE 2-3 (NO INVARIANCE, INCLUDE SES)
echo -----------------------------------------------------------------

probit dep[a] ind[one12 logm @m_age2m @b @c @d] \
	maxit[50] \
	if[(male12==0)&(white12==1)&(dd23==1)&(e==0)&(f)&(missing==0)]
calc llk2=_llk
array a_indvar = (@m_age2m @b @c @d)
calc d2 = 2+$#a_indvar
calc d2

echo
echo i.3 WAVE 1-2 (NO INVARIANCE, EXCLUDE SES)
echo -----------------------------------------------------------------

probit dep[a] ind[one12 logm @m_age1m @c @d] maxit[50] \
	if[(male12==0)&(white12==1)&(dd12==1)&(e==0)&(f)&(missing==0)]
calc llk3=_llk
array a_indvar = (@m_age1m @c @d)
calc d3 = 2+$#a_indvar
calc d3

echo
echo i.4 WAVE 2-3 (NO INVARIANCE, EXCLUDE SES)
echo -----------------------------------------------------------------

probit dep[a] ind[one12 logm @m_age2m @c @d] maxit[50] \
	if[(male12==0)&(white12==1)&(dd23==1)&(e==0)&(f)&(missing==0)]
calc llk4=_llk
array a_ivar = (@m_age2m @c @d)
calc d4 = 2+$#a_indvar
calc d4

echo
echo i.5 STACKED (FORCE INVARIANCE, INCLUDE SES)
echo -----------------------------------------------------------------

if(i==34) {
probit dep[a] ind[one1 one2 logm1 logm2 @m_age1m @m_age2m \
	@b @c @d] maxit[50] prob[p0 p1 p2 p3 p4 p5] \
	if[(male12==0)&(white12==1)&(e==0)&(f)&(missing==0)]
calc llk5=_llk 
array a_indvar = (@m_age1m @m_age2m @b @c @d)
calc d5 = 4+$#a_indvar
calc d5 }

if(i==35) {
probit dep[a] ind[one1 one2 logm1 logm2 @m_age1m @m_age2m \
	@b @c @d] maxit[50] prob[p0 p1 p2 p3 p4] \
	if[(male12==0)&(white12==1)&(e==0)&(f)&(missing==0)]
calc llk5=_llk 
array a_indvar = (@m_age1m @m_age2m @b @c @d)
calc d5 = 4+$#a_indvar
calc d5 }

if((i<=33)|(i>=36)) {
probit dep[a] ind[one1 one2 logm1 logm2 @m_age1m @m_age2m \
	@b @c @d] maxit[50] prob[p0] coef[b0] \
	covmat[Q] pred[xb0] \
	if[(male12==0)&(white12==1)&(e==0)&(f)&(missing==0)]
calc llk5=_llk
array a_indvar = (@m_age1m @m_age2m @b @c @d)
calc d5 = 4+$#a_indvar
calc d5 }

echo
echo i.6 STACKED (FORCE INVARIANCE, EXCLUDE SES)
echo -----------------------------------------------------------------

probit dep[a] ind[one1 one2 logm1 logm2 @m_age1m @m_age2m \
	@c @d] maxit[50] \
	if[(male12==0)&(white12==1)&(e==0)&(f)&(missing==0)]
calc llk6=_llk
array a_indvar = (@m_age1m @m_age2m @c @d)
calc d6 = 4+$#a_indvar
calc d6

echo
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
echo i. $a_label[i] : SIGNIFICANCE TESTS
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

echo
echo INVARIANCE TEST (INCLUDE SES)
echo -----------------------------------------------------------------

calc chi2=2*((llk1+llk2)-llk5)
calc chi2
calc df=d1+d2-d5
calc df
calc sign=1-cumchi(chi2,(d1+d2-d5))
calc sign
matrix CHI2[i,1]=chi2
matrix DF[i,1]=df

echo
echo INVARIANCE TEST (EXCLUDE SES)
echo -----------------------------------------------------------------

calc chi2=2*((llk3+llk4)-llk6)
calc chi2
calc df=d3+d4-d6
calc df
calc sign=1-cumchi(chi2,(d3+d4-d6))
calc sign
matrix CHI2[i,2]=chi2
matrix DF[i,2]=df

echo
echo SES CAUSALITY TEST (WAVE 1-2)
echo -----------------------------------------------------------------

calc chi2=2*(llk1-llk3)
calc chi2
calc df=d1-d3
calc df
calc sign=1-cumchi(chi2,d1-d3)
calc sign
matrix CHI2[i,3]=chi2
matrix DF[i,3]=df

echo
echo SES CAUSALITY TEST (WAVE 2-3)
echo -----------------------------------------------------------------

calc chi2=2*(llk2-llk4)
calc chi2
calc df=d2-d4
calc df
calc sign=1-cumchi(chi2,d2-d4)
calc sign
matrix CHI2[i,4]=chi2
matrix DF[i,4]=df

echo
echo SES CAUSALITY TEST (FORCE INVARIANCE)
echo -----------------------------------------------------------------

calc chi2=2*(llk5-llk6)
calc chi2
calc df=d5-d6
calc df
calc sign=1-cumchi(chi2,d5-d6)
calc sign
matrix CHI2[i,5]=chi2
matrix DF[i,5]=df

echo
echo JOINT TEST (INVARIANCE & SES CAUSALITY)
echo -----------------------------------------------------------------

calc chi2=2*((llk1+llk2)-llk6)
calc chi2
calc df=d1+d2-d6
calc df
calc sign=1-cumchi(chi2,(d1+d2-d6))
calc sign
matrix CHI2[i,6]=chi2
matrix DF[i,6]=df

if((i<=33)|((i>=36)&(i<=38))) {
echo
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
echo i. $a_label[i] : RELATIVE ODDS (SES)
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

range if[p0>0]
calc n=nobs
calc n

# SE CALCULATIONS
# --------------------------------------------------------------------

set z0 = b0[9]*q1wc12+b0[10]*q4wc12+b0[11]*q1ic12+b0[12]*q4ic12 \
+b0[13]*hs12+b0[14]*coll12+b0[15]*hoodpf12+b0[16]*condpf12

set z1=b0[9]+b0[11]+b0[15]+b0[16]
set z4=b0[10]+b0[12]+b0[14]
#set z2=b0[13]

set wb1=xb0+(z1-z0); if[p0>0] rp
set wb4=xb0+(z4-z0); if[p0>0] rp
#set wb2=xb0+(z2-z0); if[p0>0] rp

set p1=cumnorm(wb1); if[p0>0] rp
set p4=cumnorm(wb4); if[p0>0] rp
#set p2=cumnorm(wb2); if[p0>0] rp

range if[(p1>0)&(p4>0)]
calc m=nobs
calc m

set r41=p4/p1; if[(p4>0)&(p1>0)] rp
#set r12=p1/p2; if[(p1>0)&(p2>0)] rp
#set r42=p4/p2; if[(p4>0)&(p2>0)] rp

set k1=phi(wb1)/p1
set k4=phi(wb4)/p4
#set k2=phi(wb2)/p2

set rk1=r41*k1
set rk4=r41*k4

# SE MATIRX CALCULATIONS: high SES (4) v. low SES (1)
# --------------------------------------------------------------------

matrix R=col(r41)
matrix K1=col(k1)
matrix K4=col(k4)
matrix RK1=R.*K1
matrix RK4=R.*K4

matrix X=col(one1, one2, logm1, logm2, as70m1, as80m1, \
	as70m2, as80m2)
matrix M_SES1=col(one12, zero12, one12, zero12, zero12, \
	zero12, one12, one12)
matrix M_SES4=col(zero12, one12, zero12, one12, zero12, \
	one12, zero12, zero12)
matrix M_DEM12=col(@c)	
matrix Y=col(@d)

matrix W1={X, M_SES1, M_DEM12, Y}
matrix W4={X, M_SES4, M_DEM12, Y}

matrix A1=RK1'
matrix A4=RK4'

matrix B1=(A1*W1)'
matrix B4=(A4*W4)'
matrix B=(B4-B1)/n
matrix V=B'*Q*B

calc se41=sqrt(V)

calc lse41=(1/mean(r41))*se41

echo
echo AVERAGE RELATIVE ODDS (high SES v. low SES)
echo -----------------------------------------------------------------

calc mean(r41)
calc se41

echo
echo PERCENT CHANGE IN AVERAGE RISK (high SES v. low SES)
echo -----------------------------------------------------------------

calc log(mean(r41))
calc lse41 }

#echo
#echo AVERAGE RELATIVE ODDS (low SES v. mid SES)
#echo -----------------------------------------------------------------

#calc mean(r12)

#echo
#echo PERCENT CHANGE IN AVERAGE RISK (low SES v. mid SES)
#echo -----------------------------------------------------------------

#calc log(mean(r12))

#echo
#echo AVERAGE RELATIVE ODDS (high SES v. mid SES)
#echo -----------------------------------------------------------------

#calc mean(r42)

#echo
#echo PERCENT CHANGE IN AVERAGE RISK (high SES v. mid SES)
#echo -----------------------------------------------------------------

#calc log(mean(r42))

#cova var[p0 p1 p2 p4] byvar

range

}


# ====================================================================
# DEFINE OLS REGRESSION MACRO
# ====================================================================

config precis[digits=5]

macro r_stk(i,a,b,c) {

set missing=miss(a, one12, one1, one2, logm, logm1, logm2, \
	@m_age1m, @m_age2m, @m_ses12, @m_dem12, @b)

echo
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
echo i. $a_label[i] : PARAMETER ESTIMATES
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

echo
echo i.1 WAVE 1-2 (NO INVARIANCE, INCLUDE SES)
echo -----------------------------------------------------------------

reg dep[a] ind[one12 logm @m_age1m @m_ses12 @m_dem12 @b] rsd[rsd1] \
	if[(male12==0)&(white12==1)&(dd12==1)&(missing==0)&(c==0)]
range if[miss(rsd1)==0]
calc n=nobs
calc rss1=sum(rsd1^2)
array a_indvar=(@m_age1m @m_ses12 @m_dem12 @b)
calc df1=n-(2+$#a_indvar)
calc df1
range

echo
echo i.2 WAVE 2-3 (NO INVARIANCE, INCLUDE SES)
echo -----------------------------------------------------------------

reg dep[a] ind[one12 logm @m_age2m @m_ses12 @m_dem12 @b] rsd[rsd2] \
	if[(male12==0)&(white12==1)&(dd23==1)&(missing==0)&(c==0)]
range if[miss(rsd2)==0]
calc n=nobs
calc rss2=sum(rsd2^2)
array a_indvar=(@m_age2m @m_ses12 @m_dem12 @b)
calc df2=n-(2+$#a_indvar)
calc df2
range

echo
echo i.3 WAVE 1-2 (NO INVARIANCE, EXCLUDE SES)
echo -----------------------------------------------------------------

reg dep[a] ind[one12 logm @m_age1m @m_dem12 @b] rsd[rsd3] \
	if[(male12==0)&(white12==1)&(dd12==1)&(missing==0)&(c==0)]
range if[miss(rsd3)==0]
calc n=nobs
calc rss3=sum(rsd3^2)
array a_indvar=(@m_age1m @m_dem12 @b)
calc df3=n-(2+$#a_indvar)
calc df3
range

echo
echo i.4 WAVE 2-3 (NO INVARIANCE, EXCLUDE SES)
echo -----------------------------------------------------------------

reg dep[a] ind[one12 logm @m_age2m @m_dem12 @b] rsd[rsd4] \
	if[(male12==0)&(white12==1)&(dd23==1)&(missing==0)&(c==0)]
range if[miss(rsd4)==0]
calc n=nobs
calc rss4=sum(rsd4^2)
array a_indvar=(@m_age2m @m_dem12 @b)
calc df4=n-(2+$#a_indvar)
calc df4
range

echo
echo i.5 STACKED (FORCE INVARIANCE, INCLUDE SES)
echo -----------------------------------------------------------------

reg dep[a] ind[one1 one2 logm1 logm2 @m_age1m @m_age2m \
	@m_ses12 @m_dem12 @b] rsd[rsd5] \
	if[(male12==0)&(white12==1)&(missing==0)&(c==0)]
range if[miss(rsd5)==0]
calc n=nobs
calc rss5=sum(rsd5^2)
array a_indvar=(@m_age1m @m_age2m @m_ses12 @m_dem12 @b)
calc df5=n-(4+$#a_indvar)
calc df5
range

echo
echo i.6 STACKED (FORCE INVARIANCE, EXCLUDE SES)
echo -----------------------------------------------------------------

reg dep[a] ind[one1 one2 logm1 logm2 @m_age1m @m_age2m \
	@m_dem12 @b] rsd[rsd6] \
	if[(male12==0)&(white12==1)&(missing==0)&(c==0)]
range if[miss(rsd6)==0]
calc n=nobs
calc rss6=sum(rsd6^2)
array a_indvar=(@m_age1m @m_age2m @m_dem12 @b)
calc df6=n-(4+$#a_indvar)
calc df6
range

echo
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
echo i. $a_label[i] : SIGNIFICANCE TESTS
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

echo
echo INVARIANCE TEST (INCLUDE SES)
echo -----------------------------------------------------------------

calc fstat=((rss5-(rss1+rss2))*(df1+df2))/((df5-df1-df2)*(rss1+rss2))
calc fstat
calc df=df5-df1-df2
calc df
calc df=df1+df2
calc df
calc sign=1-cumf(fstat,(df5-df1-df2),(df1+df2))
calc sign

echo
echo INVARIANCE TEST (EXCLUDE SES)
echo -----------------------------------------------------------------

calc fstat=((rss6-(rss3+rss4))*(df3+df4))/((df6-df3-df4)*(rss3+rss4))
calc fstat
calc df=df6-df3-df4
calc df
calc df=df3+df4
calc df
calc sign=1-cumf(fstat,(df6-df3-df4),(df3+df4))
calc sign

echo
echo SES CAUSALITY TEST (WAVE 1-2)
echo -----------------------------------------------------------------

calc fstat=((rss3-rss1)*df1)/(8*rss1)
calc fstat
calc df=8
calc df
calc df=df1
calc df
calc sign=1-cumf(fstat,8,df1)
calc sign

echo
echo SES CAUSALITY TEST (WAVE 2-3)
echo -----------------------------------------------------------------

calc fstat=((rss4-rss2)*df2)/(8*rss2)
calc fstat
calc df=8
calc df
calc df=df2
calc df
calc sign=1-cumf(fstat,8,df2)
calc sign

echo
echo SES CAUSALITY TEST (FORCE INVARIANCE)
echo -----------------------------------------------------------------

calc fstat=((rss6-rss5)*df5)/(8*rss5)
calc fstat
calc df=8
calc df
calc df=df5
calc df
calc sign=1-cumf(fstat,8,df5)
calc sign

echo
echo JOINT TEST (INVARIANCE & SES CAUSALITY)
echo -----------------------------------------------------------------

calc fstat=((rss6-(rss1+rss2))*(df1+df2))/((df6-df1-df2)*(rss1+rss2))
calc fstat
calc df=df6-df1-df2
calc df
calc df=df1+df2
calc df
calc sign=1-cumf(fstat,(df6-df1-df2),(df1+df2))
calc sign

}


# ====================================================================
# DEFINE COMBINED SIGNIFICANCE TEST MACRO
# ====================================================================

config precis[digits=5]

macro m_sig(y,z,a,b,c,d,e,f,g,h,i,j,k) {

echo
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
echo y. z : COMBINED SIGNIFICANCE TESTS
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

echo
echo INVARIANCE TEST (INCLUDE SES)
echo -----------------------------------------------------------------

calc chi2=CHI2[a,1]+CHI2[b,1]+CHI2[c,1]+CHI2[d,1]+CHI2[e,1]+ \
	CHI2[f,1]+CHI2[g,1]+CHI2[h,1]+CHI2[i,1]+CHI2[j,1]+CHI2[k,1]
calc chi2
calc df=DF[a,1]+DF[b,1]+DF[c,1]+DF[d,1]+DF[e,1]+ \
	DF[f,1]+DF[g,1]+DF[h,1]+DF[i,1]+DF[j,1]+DF[k,1]
calc df
calc sign=1-cumchi(chi2,df)
calc sign

echo
echo INVARIANCE TEST (EXCLUDE SES)
echo -----------------------------------------------------------------

calc chi2=CHI2[a,2]+CHI2[b,2]+CHI2[c,2]+CHI2[d,2]+CHI2[e,2]+ \
	CHI2[f,2]+CHI2[g,2]+CHI2[h,2]+CHI2[i,2]+CHI2[j,2]+CHI2[k,2]
calc chi2
calc df=DF[a,2]+DF[b,2]+DF[c,2]+DF[d,2]+DF[e,2]+ \
	DF[f,2]+DF[g,2]+DF[h,2]+DF[i,2]+DF[j,2]+DF[k,2]
calc df
calc sign=1-cumchi(chi2,df)
calc sign

echo
echo SES CAUSALITY TEST (WAVE 1-2)
echo -----------------------------------------------------------------

calc chi2=CHI2[a,3]+CHI2[b,3]+CHI2[c,3]+CHI2[d,3]+CHI2[e,3]+ \
	CHI2[f,3]+CHI2[g,3]+CHI2[h,3]+CHI2[i,3]+CHI2[j,3]+CHI2[k,3]
calc chi2
calc df=DF[a,3]+DF[b,3]+DF[c,3]+DF[d,3]+DF[e,3]+ \
	DF[f,3]+DF[g,3]+DF[h,3]+DF[i,3]+DF[j,3]+DF[k,3]
calc df
calc sign=1-cumchi(chi2,df)
calc sign

echo
echo SES CAUSALITY TEST (WAVE 2-3)
echo -----------------------------------------------------------------

calc chi2=CHI2[a,4]+CHI2[b,4]+CHI2[c,4]+CHI2[d,4]+CHI2[e,4]+ \
	CHI2[f,4]+CHI2[g,4]+CHI2[h,4]+CHI2[i,4]+CHI2[j,4]+CHI2[k,4]
calc chi2
calc df=DF[a,4]+DF[b,4]+DF[c,4]+DF[d,4]+DF[e,4]+ \
	DF[f,4]+DF[g,4]+DF[h,4]+DF[i,4]+DF[j,4]+DF[k,4]
calc df
calc sign=1-cumchi(chi2,df)
calc sign

echo
echo SES CAUSALITY TEST (FORCE INVARIANCE)
echo -----------------------------------------------------------------

calc chi2=CHI2[a,5]+CHI2[b,5]+CHI2[c,5]+CHI2[d,5]+CHI2[e,5]+ \
	CHI2[f,5]+CHI2[g,5]+CHI2[h,5]+CHI2[i,5]+CHI2[j,5]+CHI2[k,5]
calc chi2
calc df=DF[a,5]+DF[b,5]+DF[c,5]+DF[d,5]+DF[e,5]+ \
	DF[f,5]+DF[g,5]+DF[h,5]+DF[i,5]+DF[j,5]+DF[k,5]
calc df
calc sign=1-cumchi(chi2,df)
calc sign

echo
echo JOINT TEST (INVARIANCE & SES CAUSALITY)
echo -----------------------------------------------------------------

calc chi2=CHI2[a,6]+CHI2[b,6]+CHI2[c,6]+CHI2[d,6]+CHI2[e,6]+ \
	CHI2[f,6]+CHI2[g,6]+CHI2[h,6]+CHI2[i,6]+CHI2[j,6]+CHI2[k,6]
calc chi2
calc df=DF[a,6]+DF[b,6]+DF[c,6]+DF[d,6]+DF[e,6]+ \
	DF[f,6]+DF[g,6]+DF[h,6]+DF[i,6]+DF[j,6]+DF[k,6]
calc df
calc sign=1-cumchi(chi2,df)
calc sign

}


# ====================================================================
# RUN NEW INCIDENCE HEALTH REGRESSIONS (WHITE FEMALES)
# ====================================================================


# ********************************************************************
# ********************************************************************
@p_stk(1,jcanc23,m_ses12,m_dem12,m_canc,zero,zero==0)


# ********************************************************************
# ********************************************************************
@p_stk(2,jcanc23,m_ses12,m_dem12,m_canc0,zero,canc12==0)


# ********************************************************************
# ********************************************************************
@p_stk(3,jcanc23,m_ses12,m_dem12,m_canc0,zero,canc12==1)


# ********************************************************************
# ********************************************************************
@p_stk(4,jheart23,m_ses12,m_dem12,m_heart,zero,zero==0)


# ********************************************************************
# ********************************************************************
@p_stk(5,jheart23,m_ses12,m_dem12,m_heart0,zero,heart12==0)


# ********************************************************************
# ********************************************************************
@p_stk(6,jheart23,m_ses12,m_dem12,m_heart0,zero,heart12==1)


# ********************************************************************
# ********************************************************************
@p_stk(7,jstrk23,m_ses12,m_dem12,m_strk,zero,zero==0)


# ********************************************************************
# ********************************************************************
@p_stk(8,jstrk23,m_ses12,m_dem12,m_strk0,zero,strk12==0)


# ********************************************************************
# ********************************************************************
@p_stk(9,jstrk23,m_ses12,m_dem12,m_strk0,zero,strk12==1)


# ********************************************************************
# ********************************************************************
@p_stk(10,mort23,m_ses12,m_dem12,m_mort,zero,zero==0)


# ********************************************************************
# ********************************************************************
@p_stk(11,ilung23,m_ses12,m_dem12,m_lung,mort23,lung12==0)


# ********************************************************************
# ********************************************************************
@p_stk(12,idiab23,m_ses12,m_dem12,m_diab,mort23,diab12==0)


# ********************************************************************
# ********************************************************************
@p_stk(13,ihigh23,m_ses12,m_dem12,m_high,mort23,high12==0)


# ********************************************************************
# ********************************************************************
@p_stk(14,iarth23,m_ses12,m_dem12,m_arth,mort23,arth12==0)


# ********************************************************************
# ********************************************************************
@p_stk(15,jincon23,m_ses12,m_dem12,m_incon,mort23,zero==0)


# ********************************************************************
# ********************************************************************
@p_stk(16,jincon23,m_ses12,m_dem12,m_incon0,mort23,incon12==0)


# ********************************************************************
# ********************************************************************
@p_stk(17,jincon23,m_ses12,m_dem12,m_incon0,mort23,incon12==1)


# ********************************************************************
# ********************************************************************
@p_stk(18,jfall23,m_ses12,m_dem12,m_fall,mort23,zero==0)


# ********************************************************************
# ********************************************************************
@p_stk(19,jfall23,m_ses12,m_dem12,m_fall0,mort23,fall12==0)


# ********************************************************************
# ********************************************************************
@p_stk(20,jfall23,m_ses12,m_dem12,m_fall0,mort23,fall12==1)


# ********************************************************************
# ********************************************************************
@p_stk(21,jhip23,m_ses12,m_dem12,m_hip,mort23,zero==0)


# ********************************************************************
# ********************************************************************
@p_stk(22,jhip23,m_ses12,m_dem12,m_hip0,mort23,hip12==0)


# ********************************************************************
# ********************************************************************
@p_stk(23,jhip23,m_ses12,m_dem12,m_hip0,mort23,hip12==1)


# ********************************************************************
# ********************************************************************
@p_stk(24,proxy23,m_ses12,m_dem12,m_prox,mort23,zero==0)


# ********************************************************************
# ********************************************************************
@p_stk(25,proxy23,m_ses12,m_dem12,m_prox0,mort23,proxy12==0)


# ********************************************************************
# ********************************************************************
@p_stk(26,proxy23,m_ses12,m_dem12,m_prox0b,mort23,proxy12==1)


# ********************************************************************
# ********************************************************************
@p_stk(27,icog23,m_ses12,m_dem12,m_cog,mort23,cog12==0)


# ********************************************************************
# ********************************************************************
@p_stk(28,ipsych23,m_ses12,m_dem12,m_psych,mort23,psych12==0)


# ********************************************************************
# ********************************************************************
@p_stk(29,idepr23,m_ses12,m_dem12,m_depr,mort23,depr12==0)


# ********************************************************************
# ********************************************************************
@r_stk(30,bmi23,m_bmi,mort23)


# ********************************************************************
# ********************************************************************
@p_stk(31,smok23,m_ses12,m_dem12,m_smok,mort23,zero==0)


# ********************************************************************
# ********************************************************************
@p_stk(32,smok23,m_ses12,m_dem12,m_smok0,mort23,smok12==0)


# ********************************************************************
# ********************************************************************
@p_stk(33,smok23,m_ses12,m_dem12a,m_smok0,mort23,smok12==1)


# ********************************************************************
# ********************************************************************
@p_stk(34,adl23,m_ses12,m_dem12,m_adl,mort23,zero==0)


# ********************************************************************
# ********************************************************************
@p_stk(35,iadl23,m_ses12,m_dem12,m_iadl,mort23,zero==0)


# ********************************************************************
# ********************************************************************
@p_stk(36,dhlth23,m_ses12,m_dem12,m_hlth,mort23,zero==0)


# ********************************************************************
# ********************************************************************
@p_stk(37,dhlth23,m_ses12,m_dem12,m_hlth0,mort23,dhlth12==0)


# ********************************************************************
# ********************************************************************
@p_stk(38,dhlth23,m_ses12,m_dem12,m_hlth0,mort23,dhlth12==1)


# ====================================================================
# RUN COMBINED SIGNIFICANCE TESTS (WHITE FEMALES)
# ====================================================================


# ********************************************************************
# ********************************************************************
@m_sig(1,ACCUTE,1,4,7,39,39,39,39,39,39,39,39)


# ********************************************************************
# ********************************************************************
@m_sig(2,ACCUTE_noprev,2,5,8,39,39,39,39,39,39,39,39)


# ********************************************************************
# ********************************************************************
@m_sig(3,ACCUTE_prev,3,6,9,39,39,39,39,39,39,39,39)


# ********************************************************************
# ********************************************************************
@m_sig(4,MORTALITY,10,39,39,39,39,39,39,39,39,39,39)


# ********************************************************************
# ********************************************************************
@m_sig(5,ACCUTE+MORTALITY,1,4,7,10,39,39,39,39,39,39,39)


# ********************************************************************
# ********************************************************************
@m_sig(6,DEGENERATIVE,11,12,39,39,39,39,39,39,39,39,39)


# ********************************************************************
# ********************************************************************
@m_sig(7,CHRONIC,13,14,15,39,39,39,39,39,39,39,39)


# ********************************************************************
# ********************************************************************
@m_sig(8,ACCIDENTS,18,21,39,39,39,39,39,39,39,39,39)


# ********************************************************************
# ********************************************************************
@m_sig(9,ACCIDENTS_noprev,19,22,39,39,39,39,39,39,39,39,39)


# ********************************************************************
# ********************************************************************
@m_sig(10,ACCIDENTS_prev,20,23,39,39,39,39,39,39,39,39,39)


# ********************************************************************
# ********************************************************************
@m_sig(11,MENTAL,27,28,29,39,39,39,39,39,39,39,39)


# ********************************************************************
# ********************************************************************
@m_sig(12,ALL_EXCEPT_MENTAL,1,4,7,10,11,12,13,14,15,18,21)


# ********************************************************************
# ********************************************************************
@m_sig(13,DEGENR_CHRONIC_ACCID,11,12,13,14,15,18,21,39,39,39,39)


spool off
quit
