
config more[off]
spool file[p_hww21.out]


# PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)
# FACULTY:		Dan McFadden
# AUTHOR:		Peter Adams
# LAST UPDATE:		February 07, 2003
# PROGRAM DESC:		Outfile Incidence Coeffs (White Males)


load file[~/padams/hww/probit/hww123]


save file[junk]


# ====================================================================
# DEFINE STACKED VARIABLES
# ====================================================================

# SET OBSERVATIONS
# --------------------------------------------------------------------

range obs[1-12978]
set ndx=obsno

set ndx12=ndx
match key[ndx12] file[junk]
set ndx23=ndx
match key[ndx23] file[junk]

set dd12=(ndx <= 6489)
set dd23=(1 - dd12)*(inw2==1)
set dd13=dd12|dd23

set zero=zero
set one=one

# DEFINE STACKING MACRO
# --------------------------------------------------------------------

macro stk(a,b,c) {
 set a=b; if[dd12] rp
 set a=c; if[dd23]
}

# VARIANT STACKED VARIABLES
# --------------------------------------------------------------------

@stk(one1,one,zero)
@stk(one2,zero,one)
@stk(one12,one,one)
@stk(zero12,zero,zero)

@stk(lmonth1,lmonth12,zero)
@stk(lmonth2,zero,lmonth23)
@stk(lmonth,lmonth12,lmonth23)

@stk(logm1,logm12,zero)
@stk(logm2,zero,logm23)
@stk(logm,logm12,logm23)

@stk(as70m1,as701,zero)
@stk(as70m2,zero,as702)
@stk(as70m12,as701,as702)

@stk(as80m1,as801,zero)
@stk(as80m2,zero,as802)
@stk(as80m12,as801,as802)

@stk(male12,male,male)
@stk(white12,white,white)
@stk(sample23,sample2,sample3)

# DEMOGRAPHICS
# --------------------------------------------------------------------

@stk(nevmar12,nevmarr1,nevmarr2)
@stk(widow12,widow1,widow2)
@stk(divsep12,divsep1,divsep2)
@stk(magedi12,magedie1,magedie1) 
@stk(pagedi12,pagedie1,pagedie1) 
@stk(smokev12,smokev,smokev)

# SOCIO-ECONOMIC STATUS
# --------------------------------------------------------------------

@stk(q1wc12,q1wc1,q1wc2)
@stk(q4wc12,q4wc1,q4wc2) 
@stk(q1ic12,q1ic1,q1ic2) 
@stk(q4ic12,q4ic1,q4ic2) 

@stk(q1wb12,q1wb1,q1wb2)
@stk(q4wb12,q4wb1,q4wb2) 
@stk(q1ib12,q1ib1,q1ib2) 
@stk(q4ib12,q4ib1,q4ib2) 

@stk(hs12,hs,hs) 
@stk(coll12,coll,coll) 
@stk(hoodpf12,hoodpf1,hoodpf2) 
@stk(condpf12,condpf1,condpf2)

@stk(cwlth23,cwlth2,cwlth3)

# INDEPENDENT HEALTH CONDITIONS
# --------------------------------------------------------------------

@stk(canc12,cancer1,cancer2) 
@stk(heart12,heart1,heart2)
@stk(strk12,stroke1,stroke2) 
@stk(lung12,lung1,lung2) 
@stk(diab12,diabet1,diabet2)
@stk(high12,highbp1,highbp2)
@stk(arth12,arthrt1,arthrt2)
@stk(incon12,incont1,incont2)
@stk(fall12,fall1,fall2)
@stk(hip12,hipfrc1,hipfrc2)
@stk(proxy12,proxyw1,proxyw2)
@stk(cog12,cogim1,cogim2)
@stk(psych12,psych1,psych2)
@stk(depr12,depres1,depres2)
@stk(bmi12,bmi1,bmi2)
@stk(hibmi12,hibmi1,hibmi2)
@stk(lobmi12,lobmi1,lobmi2)
@stk(smok12,smoknow1,smoknow2)
@stk(adl12,numadl1,numadl2)
@stk(iadl12,numiadl1,numiadl2)
@stk(dhlth12,dhlth1,dhlth2)

# DEPENDENT HEALTH CONDITIONS 
# --------------------------------------------------------------------

@stk(jcanc23,jcancer2,jcancer3) 
@stk(jheart23,jheart2,jheart3) 
@stk(jstrk23,jstroke2,jstroke3)
@stk(mort23,tdied2,tdied3)
@stk(ilung23,ilung2,ilung3) 
@stk(idiab23,idiabet2,idiabet3)
@stk(ihigh23,ihighbp2,ihighbp3) 
@stk(iarth23,iarthrt2,iarthrt3) 
@stk(jincon23,jincont2,jincont3)
@stk(jfall23,jfall2,jfall3) 
@stk(jhip23,jhipfrc2,jhipfrc3) 
@stk(proxy23,proxyw2,proxyw3)
@stk(icog23,icogim2,icogim3)
@stk(ipsych23,ipsych2,ipsych3) 
@stk(idepr23,idepres2,idepres3) 
@stk(bmi23,bmi2,bmi3)
@stk(bmibt23,bmibt2,bmibt3)
@stk(bmiws23,bmiws2,bmiws3)
@stk(smok23,smoknow2,smoknow3)
@stk(adl23,numadl2,numadl3)
@stk(iadl23,numiadl2,numiadl3)
@stk(dhlth23,dhlth2,dhlth3)
@stk(hoodpf23,hoodpf2,hoodpf3)
@stk(condpf23,condpf2,condpf3)


# ====================================================================
# DEFINE INDEPENDENT VARIABLE MACROS
# ====================================================================

# AGE
# --------------------------------------------------------------------

macro m_age1m { as70m1, as80m1 }
macro m_age2m { as70m2, as80m2 }
macro m_age12m { as70m12, as80m12 }

# DEMOGRAPHICS
# --------------------------------------------------------------------

macro m_dem12 { nevmar12, widow12, divsep12, magedi12, pagedi12, \
	smokev12 }
macro m_dem12a { nevmar12, widow12, divsep12, magedi12, pagedi12 }

# SOCIO-ECONOMIC STATUS
# --------------------------------------------------------------------

macro m_ses12 { q1wb12, q4wb12, q1ib12, q4ib12, hs12, coll12, \
	hoodpf12, condpf12 }

# STACKED HEALTH CONDITIONS
# --------------------------------------------------------------------

macro m_canc { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12 }

macro m_canc0 { heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12 }

macro m_heart { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23 }

macro m_heart0 { canc12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23 }

macro m_strk { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23}

macro m_strk0 { canc12, heart12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23}

macro m_mort { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23}

macro m_lung { canc12, heart12, strk12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23}

macro m_diab { canc12, heart12, strk12, lung12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23}

macro m_high { canc12, heart12, strk12, lung12, diab12, \
	arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23 }

macro m_arth { canc12, heart12, strk12, lung12, diab12, \
	high12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23 }

macro m_incon { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23 }

macro m_incon0 { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23 }

macro m_fall { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23 }

macro m_fall0 { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23 }

macro m_hip { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23 }

macro m_hip0 { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23 }

macro m_prox { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23 }

macro m_prox0 { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23 }

macro m_cog { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23, proxy23 }

macro m_psych { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23, proxy23, \
	icog23 }

macro m_depr { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23, proxy23, \
	icog23, ipsych23 }

macro m_bmi { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, bmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23, proxy23, \
	icog23, ipsych23, idepr23 }

macro m_smok { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23, proxy23, \
	icog23, ipsych23, idepr23, bmibt23, bmiws23 }

macro m_smok0 { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23, proxy23, \
	icog23, ipsych23, idepr23, bmibt23, bmiws23 }

macro m_adl { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23, proxy23, \
	icog23, ipsych23, idepr23, bmibt23, bmiws23, smok23 }

macro m_iadl { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23, proxy23, \
	icog23, ipsych23, idepr23, bmibt23, bmiws23, smok23, \
	adl23 }

macro m_hlth { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	dhlth12, jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23, proxy23, \
	icog23, ipsych23, idepr23, bmibt23, bmiws23, smok23, \
	adl23, iadl23 }

macro m_hlth0 { canc12, heart12, strk12, lung12, diab12, \
	high12, arth12, incon12, fall12, hip12, proxy12, cog12, \
	psych12, depr12, lobmi12, hibmi12, smok12, adl12, iadl12, \
	jcanc23, jheart23, jstrk23, ilung23, idiab23, \
	ihigh23, iarth23, jincon23, jfall23, jhip23, proxy23, \
	icog23, ipsych23, idepr23, bmibt23, bmiws23, smok23, \
	adl23, iadl23 }


# ====================================================================
# DEFINE DEPENDENT VARIABLE LABEL ARRAY
# ====================================================================

array a_label = ( CANCER \
	CANCER_noprev \
	CANCER_prev \
	HEART \
	HEART_noprev \
	HEART_prev \
	STROKE \
	STROKE_noprev \
	STROKE_prev \
	MORTALITY \
	LUNG \
	DIABETES \
	HIGH_BLOOD_PRESSURE \
	ARTHRITIS \
	INCONTINENCE \
	INCONTINENCE_noprev \
	INCONTINENCE_prev \
	FALL \
	FALL_noprev \
	FALL_prev \
	HIP_FRACTURE \
	HIP_FRACTURE_noprev \
	HIP_FRACTURE_prev \
	PROXY_INTERVIEW \
	PROXY_INTERVIEW_noprev \
	PROXY_INTERVIEW_prev \
	COGNITIVE_IMPAIRMENT \
	PSYCHIATRIC \
	DEPRESSION \
	BODY_MASS_INDEX \
	CURRENT_SMOKER \
	CURRENT_SMOKER_noprev \
	CURRENT_SMOKER_prev \
	ACTIVITIES_DAILY_LIVING \
	INSTRUMENTAL_ACTIVITIES_DAILY_LIVING \
	SELF_HEALTH_POOR/FAIR \
	SELF_HEALTH_POOR/FAIR_noprev \
	SELF_HEALTH_POOR/FAIR_prev )


# ====================================================================
# COEFFICIENT LABEL ARRAY
# ====================================================================

array a_coeff = ( canc canc_0 canc_1 heart heart_0 heart_1 stroke \
	stroke_0 stroke_1 mort lung diabet highbp arthrt incont \
	incont_0 incont_1 fall fall_0 fall_1 hip hip_0 hip_1 \
	proxy proxy_0 proxy_1 cogim psych depres bmi smoke smoke_0 \
	smoke_1 adl iadl dhlth dhtlh_0 dhlth_1 )
	

# ====================================================================
# DEFINE PROBIT REGRESSION MACRO
# ====================================================================

config precis[digits=8]

macro p_out(i,a,b,c,d,e,f,g) {

echo
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
echo i. $a_label[i] : PARAMETER ESTIMATES
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

echo
echo i.5 STACKED (FORCE INVARIANCE, INCLUDE SES)
echo -----------------------------------------------------------------

if((i==34)|(i==35)) {
probit dep[a] ind[logm one12 @m_age12m @b @c @d] \
	maxit[50] coef[b0] \
	if[(male12==1)&(white12==1)&(e==0)&(f)&(g)]

set $a_coeff[i]=var(b0)
}

if((i<34)|(i>35)) {
probit dep[a] ind[logm one12 @m_age12m @b @c @d] \
	maxit[50] coef[b0] prob[p0] \
	if[(male12==1)&(white12==1)&(e==0)&(f)&(g)]

set $a_coeff[i]=var(b0)
cova var[p0] if[a==0]
cova var[p0] if[a==1]
}

}


# ====================================================================
# DEFINE OLS REGRESSION MACRO
# ====================================================================

config precis[digits=8]

macro r_out(i,a,b,c) {

echo
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
echo i. $a_label[i] : PARAMETER ESTIMATES
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

echo
echo i.5 STACKED (FORCE INVARIANCE, INCLUDE SES)
echo -----------------------------------------------------------------

reg dep[a] ind[logm one12 @m_age12m @m_ses12 @m_dem12 @b] coef[b0] \
	if[(male12==1)&(white12==1)&(c==0)]

set $a_coeff[i]=var(b0)

}


# ====================================================================
# OUTFILE NEW INCIDENCE COEFFICIENTS (WHITE MALES)
# ====================================================================


# ********************************************************************
# ********************************************************************
#@p_out(1,jcanc23,m_ses12,m_dem12,m_canc,zero,zero==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(2,jcanc23,m_ses12,m_dem12,m_canc0,zero,canc12==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(3,jcanc23,m_ses12,m_dem12,m_canc0,zero,canc12==1,zero==0)


# ********************************************************************
# ********************************************************************
#@p_out(4,jheart23,m_ses12,m_dem12,m_heart,zero,zero==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(5,jheart23,m_ses12,m_dem12,m_heart0,zero,heart12==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(6,jheart23,m_ses12,m_dem12,m_heart0,zero,heart12==1,zero==0)


# ********************************************************************
# ********************************************************************
#@p_out(7,jstrk23,m_ses12,m_dem12,m_strk,zero,zero==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(8,jstrk23,m_ses12,m_dem12,m_strk0,zero,strk12==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(9,jstrk23,m_ses12,m_dem12,m_strk0,zero,strk12==1,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(10,mort23,m_ses12,m_dem12,m_mort,zero,zero==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(11,ilung23,m_ses12,m_dem12,m_lung,mort23,lung12==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(12,idiab23,m_ses12,m_dem12,m_diab,mort23,diab12==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(13,ihigh23,m_ses12,m_dem12,m_high,mort23,high12==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(14,iarth23,m_ses12,m_dem12,m_arth,mort23,arth12==0,zero==0)


# ********************************************************************
# ********************************************************************
#@p_out(15,jincon23,m_ses12,m_dem12,m_incon,mort23,zero==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(16,jincon23,m_ses12,m_dem12,m_incon0,mort23,incon12==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(17,jincon23,m_ses12,m_dem12,m_incon0,mort23,incon12==1,zero==0)


# ********************************************************************
# ********************************************************************
#@p_out(18,jfall23,m_ses12,m_dem12,m_fall,mort23,zero==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(19,jfall23,m_ses12,m_dem12,m_fall0,mort23,fall12==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(20,jfall23,m_ses12,m_dem12,m_fall0,mort23,fall12==1,zero==0)


# ********************************************************************
# ********************************************************************
#@p_out(21,jhip23,m_ses12,m_dem12,m_hip,mort23,zero==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(22,jhip23,m_ses12,m_dem12,m_hip0,mort23,hip12==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(23,jhip23,m_ses12,m_dem12,m_hip0,mort23,hip12==1,zero==0)


# ********************************************************************
# ********************************************************************
#@p_out(24,proxy23,m_ses12,m_dem12,m_prox,mort23,zero==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(25,proxy23,m_ses12,m_dem12,m_prox0,mort23,proxy12==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(26,proxy23,m_ses12,m_dem12,m_prox0,mort23,proxy12==1,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(27,icog23,m_ses12,m_dem12,m_cog,mort23,cog12==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(28,ipsych23,m_ses12,m_dem12,m_psych,mort23,psych12==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(29,idepr23,m_ses12,m_dem12,m_depr,mort23,depr12==0,zero==0)


# ********************************************************************
# ********************************************************************
@r_out(30,bmi23,m_bmi,mort23)


# ********************************************************************
# ********************************************************************
#@p_out(31,smok23,m_ses12,m_dem12,m_smok,mort23,zero==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(32,smok23,m_ses12,m_dem12,m_smok0,mort23,smok12==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(33,smok23,m_ses12,m_dem12a,m_smok0,mort23,smok12==1,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(34,adl23,m_ses12,m_dem12,m_adl,mort23,zero==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(35,iadl23,m_ses12,m_dem12,m_iadl,mort23,zero==0,zero==0)


# ********************************************************************
# ********************************************************************
#@p_out(36,dhlth23,m_ses12,m_dem12,m_hlth,mort23,zero==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(37,dhlth23,m_ses12,m_dem12,m_hlth0,mort23,dhlth12==0,zero==0)


# ********************************************************************
# ********************************************************************
@p_out(38,dhlth23,m_ses12,m_dem12,m_hlth0,mort23,dhlth12==1,zero==0)


# ====================================================================
# OUTFILE COEFFICIENTS
# ====================================================================

save file[~/padams/hww/simul/rawdata/icoeff_wm] var[canc_0 canc_1 \
	heart_0 heart_1 stroke_0 \
	stroke_1 mort lung diabet highbp arthrt incont_0 incont_1 \
	fall_0 fall_1 hip_0 hip_1 proxy_0 cogim psych \
	depres bmi smoke_0 smoke_1 adl iadl dhtlh_0 dhlth_1] dbase


spool off
quit
